import { Module } from '@nestjs/common';
import { TypeOrmModule } from '@nestjs/typeorm';

import { GameController } from './game.controller';
import { GameService } from './game.service';
import {
  GameEntity,
  Game_PersonEntity,
  ObjectivePointEntity,
  ObjectivePoint_HistoryEntity,
} from './game.entity';
import { PersonEntity } from '../user/user.entity';
import { GameGroupEntity } from '../faction/faction.entity';
import { FactionEntity } from '../faction/faction.entity';
import { NotificationModule } from '../notifications/notifications.module';
import { TickService } from './tick.service';
import { ScoreService } from '../score/score.service';
import { ScoreEntity } from '../score/score.entity';
import { MulterModule } from '@nestjs/platform-express';

/////////////////////////////////////////////////////////////////////
/// Game                                                          ///
/// - contains everything to do with Game data                    ///
/////////////////////////////////////////////////////////////////////
@Module({
  imports: [
    TypeOrmModule.forFeature([
      GameEntity,
      FactionEntity,
      Game_PersonEntity,
      PersonEntity,
      GameGroupEntity,
      ObjectivePointEntity,
      ObjectivePoint_HistoryEntity,
      ScoreEntity,
    ]),
    NotificationModule,
    MulterModule.register({
      dest: './images',
    }),
  ],
  controllers: [GameController],
  providers: [GameService, TickService, ScoreService],
})
export class GameModule {}
